==> core-react-0.8.0.tgz: package/es/Icon/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Icon = function Icon(props) {
  var className = props.className,
      type = props.type,
      src = props.src,
      other = _objectWithoutProperties(props, ["className", "type", "src"]);

  return React.createElement("i", _extends({
    className: cx("".concat("waui", "-icon"), _defineProperty({}, "".concat("waui", "-icon__").concat(type), type), className)
  }, other), src && React.createElement("svg", null, React.createElement("use", {
    xlinkHref: src
  })));
};

Icon.propTypes = {
  className: PropTypes.string,

  /** icon type */
  type: PropTypes.string,

  /** icon src, such as svg `xlinkHref` */
  src: PropTypes.string
};
export default Icon;

==> core-react-0.8.2.tgz: package/es/Icon/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Icon = function Icon(props) {
  var className = props.className,
      type = props.type,
      src = props.src,
      other = _objectWithoutProperties(props, ["className", "type", "src"]);

  return (/*#__PURE__*/React.createElement("i", _extends({
      className: cx("".concat("waui", "-icon"), _defineProperty({}, "".concat("waui", "-icon__").concat(type), type), className)
    }, other), src && /*#__PURE__*/React.createElement("svg", null, /*#__PURE__*/React.createElement("use", {
      xlinkHref: src
    })))
  );
};

Icon.propTypes = {
  className: PropTypes.string,

  /** icon type */
  type: PropTypes.string,

  /** icon src, such as svg `xlinkHref` */
  src: PropTypes.string
};
export default Icon;
